@@ -48,7 +48,7 @@ module when designing alternate methods for text segmentation.
 
 =head1 AUTHORS
 
-David James <david@jamesgang.com>
+David James <splice@cpan.org>
 
 =head1 SEE ALSO
 
@@ -64,7 +64,7 @@ L<http://www.cs.toronto.edu/~james>
 
 =cut
 
-$VERSION = 0.09;
+$VERSION = 0.10;
 @EXPORT_OK = qw(
     segment
     segments
