@@ -54,7 +54,7 @@ exported.
 
 =head1 AUTHORS
 
-David James <david@jamesgang.com>
+David James <splice@cpan.org>
 
 =head1 SEE ALSO
 
@@ -63,7 +63,7 @@ L<http://www.cs.toronto.edu/~james>
 
 =cut
 
-$VERSION = 0.09;
+$VERSION = 0.10;
 @EXPORT_OK = qw(
     words 
     paragraphs 
